@@ -65,6 +65,31 @@ def sync_customers():
     LOGS.logger.info("Sync customers from CRM -- END")
 
 
+@cmd.command()
+def fup_or_defup():
+    """Udpate all customers total comsumption"""
+    limits = {
+        'business_access': {'limit': 50, 'policy': 'business_access_1'},
+        'business_plus': {'limit': 150, 'policy': 'business_plus_1'}
+    }
+    LOGS.logger.info("Update customers consumption -- START")
+    customers_si = core.get_customers_si()
+    for customer in customers_si:
+        product = customer['product']
+        data_limit = limits[product]['limit']
+        customer_name = customer['name']
+        policy = limits[product]['policy']
+        consumption = core.get_consommation_sum(customer_name)
+        fup_status = consumption > data_limit
+        core.update_consommation(product, policy, customer_name, fup_status, consumption)
+
+        # if fup_status:
+        #     core.fup_customer(customer_name)
+        # else:
+        #     core.defup_customer(customer_name)
+    LOGS.logger.info("Sync customers from CRM -- END")
+
+
 @cmd.command()
 @click.option('--last-date', default=False)
 @click.option('--product-ese', is_flag=True, default=False)
