@@ -448,7 +448,7 @@ def get_product_policy(product):
 # =============================== CDRs =====================================
 
 def update_consommation(product, policy, customer_name, fup_status, consumption):
-    yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%M-%d")
+    yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%m-%d")
     sql = (
         "INSERT INTO fup(product, policy, customer, datetime, status, conso)"
         "VALUES ('{product}', '{policy}', '{customer}', '{date}', '{status}','{consumption}');"
@@ -480,7 +480,7 @@ def get_consommation_sum(customer):
     """
     Fetches the last 30days consumptions of a customer
     """
-    yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%M-%d")
+    yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%m-%d")
     sql = (
         "SELECT SUM(octets_in+octets_out) "
         "FROM cdr "
@@ -566,7 +566,7 @@ def send_error_report(operation, error):
 
     LOGS.logger.info(
         "Email: '{}' sent to {}".format(msg['Subject'], destinations))
-    smtp.quit()
+
     # message = (
     #     "Service: {} [{}]\n\n"
     #     "Affected operation: {}\n\n"
